@@ -1,6 +1,9 @@
 {-# LANGUAGE PatternGuards, TypeSynonymInstances, FlexibleInstances #-}
 
-module HSE.Bracket where
+module HSE.Bracket(
+    Brackets(..),
+    paren, transformBracket, rebracket1, appsBracket
+    ) where
 
 import HSE.Type
 import HSE.Util
@@ -77,7 +80,8 @@ instance Brackets Type_ where
 
     needBracket i parent child
         | isAtom child = False
-        | TyFun{} <- parent, i == 1, TyFun{} <- child = False
+-- a -> (b -> c) is not a required bracket, but useful for documentation about arity etc.
+--        | TyFun{} <- parent, i == 1, TyFun{} <- child = False
         | TyFun{} <- parent, TyApp{} <- child = False
         | TyTuple{} <- parent = False
         | TyList{} <- parent = False
