@@ -1,6 +1,6 @@
 {-# LANGUAGE FlexibleContexts #-}
 
-module HSE.Util where
+module HSE.Util(module HSE.Util) where
 
 import Control.Monad
 import Data.List
@@ -101,6 +101,7 @@ isQuasiQuote QuasiQuote{} = True; isQuasiQuote _ = False
 isSpliceDecl SpliceDecl{} = True; isSpliceDecl _ = False
 isNewType NewType{} = True; isNewType _ = False
 isRecStmt RecStmt{} = True; isRecStmt _ = False
+isClsDefSig ClsDefSig{} = True; isClsDefSig _ = False
 
 isSection LeftSection{} = True
 isSection RightSection{} = True
